@@ -21,26 +21,20 @@
 #include "dictionarycreationwizard.h"
 #include "wordlist.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QCheckBox>
-#include <QtGui/QRadioButton>
-#include <QtGui/QLineEdit>
-#include <QtGui/QGridLayout>
-#include <QtCore/QTextCodec>
-#include <QtCore/QTextStream>
+#include <QCheckBox>
+#include <QLocale>
+#include <QGridLayout>
 #include <QProgressDialog>
+#include <QRadioButton>
+#include <QSpinBox>
+#include <QStandardPaths>
+#include <QTextCodec>
+#include <QTextStream>
+
 #include <QDebug>
 
-#include <k3listview.h>
-#include <klineedit.h>
-#include <kurlrequester.h>
-#include <klocale.h>
-#include <kcombobox.h>
-#include <kapplication.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
-#include <klanguagebutton.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 int CreationSourceWidget::nextId() const
 {
@@ -121,7 +115,7 @@ void DictionaryCreationWizard::buildCodecList()
 
 void DictionaryCreationWizard::buildCodecCombo(KComboBox *combo)
 {
-    QString local = i18nc("Local characterset", "Local") + QLatin1String(" (");
+    QString local = i18nc("Local characterset", "Local") + QStringLiteral(" (");
     local += QLatin1String(QTextCodec::codecForLocale()->name()) + QLatin1Char(')');
     combo->addItem(local, 0);
     combo->addItem(i18nc("Latin characterset", "Latin1"), 1);
@@ -195,11 +189,11 @@ QString DictionaryCreationWizard::createDictionary()
     QString dictionaryFile;
     do {
         dictnumber++;
-        filename = QString(QLatin1String("wordcompletion%1.dict")).arg(dictnumber);
-        dictionaryFile = KGlobal::dirs()->findResource("appdata", filename);
-    } while (KStandardDirs::exists(dictionaryFile));
+        filename = QStringLiteral("wordcompletion%1.dict").arg(dictnumber);
+        dictionaryFile = QStandardPaths::locate(QStandardPaths::DataLocation, filename);
+    } while (QFile::exists(dictionaryFile));
 
-    dictionaryFile = KGlobal::dirs()->saveLocation("appdata", QLatin1String("/")) + filename;
+    dictionaryFile = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("/") + filename;
     if (WordList::saveWordList(map, dictionaryFile))
         return filename;
     else
@@ -226,10 +220,7 @@ QString DictionaryCreationWizard::language()
     if (creationSource->mergeButton->isChecked()) {
         return mergeWidget->language();
     } else if (creationSource->emptyButton->isChecked()) {
-        if (KGlobal::locale())
-            return KGlobal::locale()->language();
-        else
-            return KLocale::defaultLanguage();
+        return QLocale::languageToString(QLocale::system().language());
     } else if (creationSource->fileButton->isChecked()) {
         return fileWidget->languageButton->current();
     } else if (creationSource->directoryButton->isChecked()) {
@@ -256,18 +247,18 @@ MergeWidget::MergeWidget(QWidget *parent, const char *name,
     QStringList::ConstIterator lIt = dictionaryLanguages.begin();
     for (; nIt != dictionaryNames.end(); ++nIt, ++fIt, ++lIt) {
         QCheckBox *checkbox = new QCheckBox(*nIt, this);
-        KIntNumInput *numInput = new KIntNumInput(this);
+        QSpinBox *spinBox = new QSpinBox(this);
         layout->addWidget(checkbox, row, 0);
-        layout->addWidget(numInput, row, 1);
+        layout->addWidget(spinBox, row, 1);
 
         checkbox->setChecked(true);
-        numInput->setRange(1, 100, 10);
-        numInput->setSliderEnabled(true);
-        numInput->setValue(100);
-        connect(checkbox, SIGNAL(toggled(bool)), numInput, SLOT(setEnabled(bool)));
+        spinBox->setRange(1, 100);
+        spinBox->setSingleStep(10);
+        spinBox->setValue(100);
+        connect(checkbox, &QAbstractButton::toggled, spinBox, &QWidget::setEnabled);
 
         dictionaries.insert(*fIt, checkbox);
-        weights.insert(*fIt, numInput);
+        weights.insert(*fIt, spinBox);
         languages [*fIt] = *lIt;
         row++;
     }
@@ -286,7 +277,7 @@ QMap <QString, int> MergeWidget::mergeParameters()
         it.next();
         if (it.value()->isChecked()) {
             QString name = it.key();
-            QString dictionaryFile = KGlobal::dirs()->findResource("appdata", name);
+            QString dictionaryFile = QStandardPaths::locate(QStandardPaths::DataLocation, name);
             files[dictionaryFile] = weights.value(name)->value();
         }
     }
@@ -320,7 +311,7 @@ CompletionWizardWidget::~CompletionWizardWidget()
 {
 }
 
-void CompletionWizardWidget::ok(KConfig *config)
+void CompletionWizardWidget::ok()
 {
     WordList::WordMap map;
     QProgressDialog *pdlg = WordList::progressDialog();
@@ -337,10 +328,10 @@ void CompletionWizardWidget::ok(KConfig *config)
     QString filename;
     QString dictionaryFile;
 
-    dictionaryFile = KGlobal::dirs()->saveLocation("appdata", QLatin1String("/")) + QLatin1String("wordcompletion1.dict");
+    dictionaryFile = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("/");
     qDebug() << "dictionaryFile is " << dictionaryFile;
     if (WordList::saveWordList(map, dictionaryFile)) {
-        KConfigGroup cg(config, "Dictionary 0");
+        KConfigGroup cg(KSharedConfig::openConfig(), "Dictionary 0");
         cg.writeEntry("Filename", "wordcompletion1.dict");
         cg.writeEntry("Name",     i18nc("Default dictionary", "Default"));
         cg.writeEntry("Language", language);
